Gain

pub struct Gain {
    pub type_: Option<GainType>,
    pub domain: Option<GainDomain>,
    pub min_gain: Option<f32>,
    pub max_gain: Option<f32>,
    pub min_gain_step: Option<f32>,
    /* private fields */
}
Parameters for an Element with type equal to GAIN.

Fields

type_: Option<GainType>

Specifies what the numbers for gain represent, e.g. a percentage.

Required.

domain: Option<GainDomain>

If included, the gain is applied in the specified GainDomain. If not included, the gain domain is unspecified.

Optional.

min_gain: Option<f32>

Minimum gain in GainType format.

Required. Must be finite.

max_gain: Option<f32>

Maximum gain in GainType format.

Required. Must be finite.

min_gain_step: Option<f32>

Minimum gain step in GainType format, this value must not be negative, but may be zero to convey an effectively continuous range of values. Must not exceed max_gain - min_gain. The actual gain set may be queried by the client with a WatchElementState call.

Required. Must be finite.